@@ -1,23 +1,27 @@
-import React, { PureComponent } from 'react';
+import { PureComponent } from 'react';
 import { connect } from 'react-redux';
 
-import { SelectableValue, dateTime } from '@grafana/data';
-import { Drawer, Tab, TabsBar, TabContent, Themeable2, withTheme2 } from '@grafana/ui';
+import { dateTime, SelectableValue } from '@grafana/data';
+import { config } from '@grafana/runtime';
+import { Drawer, Tab, TabContent, TabsBar, Themeable2, withTheme2 } from '@grafana/ui';
 import { UpgradeBox } from 'app/core/components/Upgrade/UpgradeBox';
 import { highlightTrial } from 'app/features/admin/utils';
+import { isPublicDashboardsEnabled } from 'app/features/dashboard/components/ShareModal/SharePublicDashboard/SharePublicDashboardUtils';
 import { DashboardModel } from 'app/features/dashboard/state';
 
 import { AnalyticsTab, EnterpriseStoreState } from '../../types';
 import {
   DAILY_SUMMARY_DATE_FORMAT,
   DashboardDailySummaryDTO,
-  UserViewDTO,
   getDashboardDailySummaries,
+  getPublicDashboardDailySummaries,
   getUserViews,
+  UserViewDTO,
 } from '../api';
 import { setDrawerOpen, setDrawerTab } from '../state/reducers';
 import { getInsightsStyles, InsightsStyles } from '../styles';
 
+import AnalyticsPublicDashboardsTab from './AnalyticsPublicDashboardsTab';
 import AnalyticsStatsTab from './AnalyticsStatsTab';
 import AnalyticsUsersTab from './AnalyticsUsersTab';
 
@@ -29,8 +33,8 @@ interface Props extends Themeable2 {
 }
 
 interface State {
-  drawerWidth: string;
   dailySummaries: DashboardDailySummaryDTO[];
+  publicDailySummaries: DashboardDailySummaryDTO[];
   userViews: UserViewDTO[];
 }
 
@@ -40,8 +44,8 @@ class AnalyticsDrawer extends PureComponent<Props, State> {
   constructor(props: Props) {
     super(props);
     this.state = {
-      drawerWidth: '50%',
       dailySummaries: [],
+      publicDailySummaries: [],
       userViews: [],
     };
   }
@@ -56,7 +60,13 @@ class AnalyticsDrawer extends PureComponent<Props, State> {
     if (dashboard?.id && dashboard.meta.url) {
       const dailySummaries = await getDashboardDailySummaries(dashboard.id, days);
       const userViews = await getUserViews(dashboard.id, USER_LIMIT);
-      this.setState({ dailySummaries, userViews });
+
+      let publicDailySummaries: DashboardDailySummaryDTO[] = [];
+      if (isPublicDashboardsEnabled()) {
+        publicDailySummaries = await getPublicDashboardDailySummaries(dashboard.id, days);
+      }
+
+      this.setState({ dailySummaries, userViews, publicDailySummaries });
     }
   }
 
@@ -70,6 +80,13 @@ class AnalyticsDrawer extends PureComponent<Props, State> {
       { label: 'Users and activity', value: AnalyticsTab.Users },
     ];
 
+    if (isPublicDashboardsEnabled()) {
+      tabs.push({
+        label: config.featureToggles.newDashboardSharingComponent ? 'Shared dashboards' : 'Public dashboards',
+        value: AnalyticsTab.PublicDashboards,
+      });
+    }
+
     return (
       <TabsBar className={styles.tabsBar}>
         {tabs.map((t, index) => (
@@ -85,7 +102,7 @@ class AnalyticsDrawer extends PureComponent<Props, State> {
   }
 
   render() {
-    const { dailySummaries, drawerWidth, userViews } = this.state;
+    const { dailySummaries, publicDailySummaries, userViews } = this.state;
     const { dashboard, drawerTab, setDrawerOpen, theme } = this.props;
     const styles = getInsightsStyles(theme);
 
@@ -93,7 +110,7 @@ class AnalyticsDrawer extends PureComponent<Props, State> {
       <Drawer
         scrollableContent
         title={`${dashboard.title} - analytics`}
-        width={drawerWidth}
+        size="md"
         onClose={() => setDrawerOpen(false)}
         subtitle={this.renderHeader(styles)}
         expandable
@@ -113,6 +130,9 @@ class AnalyticsDrawer extends PureComponent<Props, State> {
           {drawerTab === AnalyticsTab.Users && (
             <AnalyticsUsersTab dashboard={dashboard} dailySummaries={dailySummaries} userViews={userViews} />
           )}
+          {isPublicDashboardsEnabled() && drawerTab === AnalyticsTab.PublicDashboards && (
+            <AnalyticsPublicDashboardsTab dashboard={dashboard} dailySummaries={publicDailySummaries} />
+          )}
         </TabContent>
       </Drawer>
     );
